Jig
===

A command line tool and framework for getting more from the Git pre-commit
hook.

What is the Git pre-commit hook? It's a small script that Git automatically
runs right before you commit.

Installation
------------

The Jig_ command line tool is written in Python, you can write plugins in any
language you wish. Install the tool by:

::

    $ pip install jig || easy_install jig

Getting started
---------------

You can give Jig a spin in less than 5 minutes

`Take me to the quick start`_

It's super easy to write your own plugins too

`Show me how to write plugins`_

.. _Take me to the quick start: http://packages.python.org/jig/index.html
.. _Show me how to write plugins: http://packages.python.org/jig/pluginapi.html
.. _Jig: http://pypi.python.org/pypi/jig

Support
-------

Problems or requests? Create an issue on GitHub.

http://github.com/robmadole/jig/issues
